@@ -104,8 +104,10 @@ import aws_cdk.aws_kinesisfirehose
 import aws_cdk.aws_kms
 import aws_cdk.aws_lambda
 import aws_cdk.aws_lambda_event_sources
+import aws_cdk.aws_mediastore
 import aws_cdk.aws_s3
 import aws_cdk.aws_sagemaker
+import aws_cdk.aws_secretsmanager
 import aws_cdk.aws_sns
 import aws_cdk.aws_sqs
 
@@ -286,7 +288,7 @@ class BuildDeadLetterQueueProps:
         '''
         :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
         :param deploy_dead_letter_queue: Whether to deploy a secondary queue to be used as a dead letter queue. Default: - required field.
-        :param existing_queue_obj: Existing instance of SQS queue object, if this is set then the queueProps is ignored. Default: - None.
+        :param existing_queue_obj: Existing instance of SQS queue object, providing both this and queueProps will cause an error. Default: - None.
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue. Default: - Default props are used
         '''
         if isinstance(dead_letter_queue_props, dict):
@@ -321,7 +323,7 @@ class BuildDeadLetterQueueProps:
 
     @builtins.property
     def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
-        '''Existing instance of SQS queue object, if this is set then the queueProps is ignored.
+        '''Existing instance of SQS queue object, providing both this and queueProps will cause an error.
 
         :default: - None.
         '''
@@ -366,7 +368,7 @@ class BuildDynamoDBTableProps:
     ) -> None:
         '''
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
-        :param existing_table_obj: Existing instance of dynamodb table object. If this is set then the dynamoTableProps is ignored Default: - None
+        :param existing_table_obj: Existing instance of dynamodb table object. Providing both this and ``dynamoTableProps`` will cause an error. Default: - None
         '''
         if isinstance(dynamo_table_props, dict):
             dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
@@ -389,7 +391,7 @@ class BuildDynamoDBTableProps:
     def existing_table_obj(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
         '''Existing instance of dynamodb table object.
 
-        If this is set then the dynamoTableProps is ignored
+        Providing both this and ``dynamoTableProps`` will cause an error.
 
         :default: - None
         '''
@@ -565,7 +567,7 @@ class BuildKinesisStreamProps:
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
     ) -> None:
         '''
-        :param existing_stream_obj: Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
+        :param existing_stream_obj: Existing instance of Kinesis Stream, providing both this and ``kinesisStreamProps`` will cause an error. Default: - None
         :param kinesis_stream_props: Optional user provided props to override the default props for the Kinesis stream. Default: - Default props are used.
         '''
         if isinstance(kinesis_stream_props, dict):
@@ -578,7 +580,7 @@ class BuildKinesisStreamProps:
 
     @builtins.property
     def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
-        '''Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.
+        '''Existing instance of Kinesis Stream, providing both this and ``kinesisStreamProps`` will cause an error.
 
         :default: - None
         '''
@@ -624,7 +626,7 @@ class BuildLambdaFunctionProps:
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
     ) -> None:
         '''
-        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param existing_lambda_obj: Existing instance of Lambda Function object, Providing both this and lambdaFunctionProps will cause an error. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
         :param vpc: A VPC where the Lambda function will access internal resources. Default: - none
         '''
@@ -640,7 +642,7 @@ class BuildLambdaFunctionProps:
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        '''Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
+        '''Existing instance of Lambda Function object, Providing both this and lambdaFunctionProps will cause an error.
 
         :default: - None
         '''
@@ -707,7 +709,7 @@ class BuildQueueProps:
         :param enable_encryption_with_customer_managed_key: Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct. Default: - false (encryption enabled with AWS Managed KMS Key).
         :param encryption_key: An optional, imported encryption key to encrypt the SQS queue with. Default: - not specified.
         :param encryption_key_props: Optional user-provided props to override the default props for the encryption key. Default: - Ignored if encryptionKey is provided
-        :param existing_queue_obj: Existing instance of SQS queue object, if this is set then the queueProps is ignored. Default: - None.
+        :param existing_queue_obj: Existing instance of SQS queue object, providing both this and queueProps will cause an error. Default: - None.
         :param queue_props: Optional user provided props to override the default props for the primary queue. Default: - Default props are used.
         '''
         if isinstance(dead_letter_queue, dict):
@@ -773,7 +775,7 @@ class BuildQueueProps:
 
     @builtins.property
     def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
-        '''Existing instance of SQS queue object, if this is set then the queueProps is ignored.
+        '''Existing instance of SQS queue object, providing both this and queueProps will cause an error.
 
         :default: - None.
         '''
@@ -1060,7 +1062,7 @@ class BuildTopicProps:
         :param enable_encryption_with_customer_managed_key: Use a Customer Managed KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct. Default: - false (encryption enabled with AWS Managed KMS Key).
         :param encryption_key: An optional, imported encryption key to encrypt the SNS topic with. Default: - not specified.
         :param encryption_key_props: Optional user-provided props to override the default props for the encryption key. Default: - Ignored if encryptionKey is provided
-        :param existing_topic_obj: Existing instance of SNS Topic object, if this is set then the TopicProps is ignored. Default: - None.
+        :param existing_topic_obj: Existing instance of SNS Topic object, providing both this and ``topicProps`` will cause an error. Default: - None.
         :param topic_props: Optional user provided props to override the default props for the SNS topic. Default: - Default props are used.
         '''
         if isinstance(encryption_key_props, dict):
@@ -1113,7 +1115,7 @@ class BuildTopicProps:
 
     @builtins.property
     def existing_topic_obj(self) -> typing.Optional[aws_cdk.aws_sns.Topic]:
-        '''Existing instance of SNS Topic object, if this is set then the TopicProps is ignored.
+        '''Existing instance of SNS Topic object, providing both this and ``topicProps`` will cause an error.
 
         :default: - None.
         '''
@@ -1484,6 +1486,8 @@ class ServiceEndpointTypes(enum.Enum):
     S3 = "S3"
     STEPFUNCTIONS = "STEPFUNCTIONS"
     SAGEMAKER_RUNTIME = "SAGEMAKER_RUNTIME"
+    SECRETS_MANAGER = "SECRETS_MANAGER"
+    SSM = "SSM"
 
 
 @jsii.data_type(
@@ -1577,6 +1581,349 @@ class SinkStoreType(enum.Enum):
     S3 = "S3"
 
 
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/core.VerifiedProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "bucket_props": "bucketProps",
+        "dead_letter_queue_props": "deadLetterQueueProps",
+        "deploy_dead_letter_queue": "deployDeadLetterQueue",
+        "deploy_vpc": "deployVpc",
+        "dynamo_table_props": "dynamoTableProps",
+        "encryption_key": "encryptionKey",
+        "encryption_key_props": "encryptionKeyProps",
+        "endpoint_props": "endpointProps",
+        "existing_bucket_obj": "existingBucketObj",
+        "existing_glue_job": "existingGlueJob",
+        "existing_lambda_obj": "existingLambdaObj",
+        "existing_media_store_container_obj": "existingMediaStoreContainerObj",
+        "existing_queue_obj": "existingQueueObj",
+        "existing_sagemaker_endpoint_obj": "existingSagemakerEndpointObj",
+        "existing_secret_obj": "existingSecretObj",
+        "existing_stream_obj": "existingStreamObj",
+        "existing_table_obj": "existingTableObj",
+        "existing_topic_obj": "existingTopicObj",
+        "existing_vpc": "existingVpc",
+        "glue_job_props": "glueJobProps",
+        "kinesis_stream_props": "kinesisStreamProps",
+        "lambda_function_props": "lambdaFunctionProps",
+        "media_store_container_props": "mediaStoreContainerProps",
+        "queue_props": "queueProps",
+        "secret_props": "secretProps",
+        "topic_props": "topicProps",
+        "topics_props": "topicsProps",
+        "vpc_props": "vpcProps",
+    },
+)
+class VerifiedProps:
+    def __init__(
+        self,
+        *,
+        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+        deploy_vpc: typing.Optional[builtins.bool] = None,
+        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+        encryption_key_props: typing.Optional[aws_cdk.aws_kms.KeyProps] = None,
+        endpoint_props: typing.Optional[aws_cdk.aws_sagemaker.CfnEndpointProps] = None,
+        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
+        existing_glue_job: typing.Optional[aws_cdk.aws_glue.CfnJob] = None,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        existing_media_store_container_obj: typing.Optional[aws_cdk.aws_mediastore.CfnContainer] = None,
+        existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
+        existing_sagemaker_endpoint_obj: typing.Optional[aws_cdk.aws_sagemaker.CfnEndpoint] = None,
+        existing_secret_obj: typing.Optional[aws_cdk.aws_secretsmanager.Secret] = None,
+        existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+        existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
+        existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
+        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        glue_job_props: typing.Optional[aws_cdk.aws_glue.CfnJobProps] = None,
+        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        media_store_container_props: typing.Optional[aws_cdk.aws_mediastore.CfnContainerProps] = None,
+        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        secret_props: typing.Optional[aws_cdk.aws_secretsmanager.SecretProps] = None,
+        topic_props: typing.Optional[aws_cdk.aws_sns.TopicProps] = None,
+        topics_props: typing.Optional[aws_cdk.aws_sns.TopicProps] = None,
+        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+    ) -> None:
+        '''
+        :param bucket_props: -
+        :param dead_letter_queue_props: -
+        :param deploy_dead_letter_queue: -
+        :param deploy_vpc: -
+        :param dynamo_table_props: -
+        :param encryption_key: -
+        :param encryption_key_props: -
+        :param endpoint_props: -
+        :param existing_bucket_obj: -
+        :param existing_glue_job: -
+        :param existing_lambda_obj: -
+        :param existing_media_store_container_obj: -
+        :param existing_queue_obj: -
+        :param existing_sagemaker_endpoint_obj: -
+        :param existing_secret_obj: -
+        :param existing_stream_obj: -
+        :param existing_table_obj: -
+        :param existing_topic_obj: -
+        :param existing_vpc: -
+        :param glue_job_props: -
+        :param kinesis_stream_props: -
+        :param lambda_function_props: -
+        :param media_store_container_props: -
+        :param queue_props: -
+        :param secret_props: -
+        :param topic_props: -
+        :param topics_props: -
+        :param vpc_props: -
+        '''
+        if isinstance(bucket_props, dict):
+            bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
+        if isinstance(dead_letter_queue_props, dict):
+            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
+        if isinstance(dynamo_table_props, dict):
+            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
+        if isinstance(encryption_key_props, dict):
+            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
+        if isinstance(endpoint_props, dict):
+            endpoint_props = aws_cdk.aws_sagemaker.CfnEndpointProps(**endpoint_props)
+        if isinstance(glue_job_props, dict):
+            glue_job_props = aws_cdk.aws_glue.CfnJobProps(**glue_job_props)
+        if isinstance(kinesis_stream_props, dict):
+            kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(**kinesis_stream_props)
+        if isinstance(lambda_function_props, dict):
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+        if isinstance(media_store_container_props, dict):
+            media_store_container_props = aws_cdk.aws_mediastore.CfnContainerProps(**media_store_container_props)
+        if isinstance(queue_props, dict):
+            queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
+        if isinstance(secret_props, dict):
+            secret_props = aws_cdk.aws_secretsmanager.SecretProps(**secret_props)
+        if isinstance(topic_props, dict):
+            topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
+        if isinstance(topics_props, dict):
+            topics_props = aws_cdk.aws_sns.TopicProps(**topics_props)
+        if isinstance(vpc_props, dict):
+            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+        self._values: typing.Dict[str, typing.Any] = {}
+        if bucket_props is not None:
+            self._values["bucket_props"] = bucket_props
+        if dead_letter_queue_props is not None:
+            self._values["dead_letter_queue_props"] = dead_letter_queue_props
+        if deploy_dead_letter_queue is not None:
+            self._values["deploy_dead_letter_queue"] = deploy_dead_letter_queue
+        if deploy_vpc is not None:
+            self._values["deploy_vpc"] = deploy_vpc
+        if dynamo_table_props is not None:
+            self._values["dynamo_table_props"] = dynamo_table_props
+        if encryption_key is not None:
+            self._values["encryption_key"] = encryption_key
+        if encryption_key_props is not None:
+            self._values["encryption_key_props"] = encryption_key_props
+        if endpoint_props is not None:
+            self._values["endpoint_props"] = endpoint_props
+        if existing_bucket_obj is not None:
+            self._values["existing_bucket_obj"] = existing_bucket_obj
+        if existing_glue_job is not None:
+            self._values["existing_glue_job"] = existing_glue_job
+        if existing_lambda_obj is not None:
+            self._values["existing_lambda_obj"] = existing_lambda_obj
+        if existing_media_store_container_obj is not None:
+            self._values["existing_media_store_container_obj"] = existing_media_store_container_obj
+        if existing_queue_obj is not None:
+            self._values["existing_queue_obj"] = existing_queue_obj
+        if existing_sagemaker_endpoint_obj is not None:
+            self._values["existing_sagemaker_endpoint_obj"] = existing_sagemaker_endpoint_obj
+        if existing_secret_obj is not None:
+            self._values["existing_secret_obj"] = existing_secret_obj
+        if existing_stream_obj is not None:
+            self._values["existing_stream_obj"] = existing_stream_obj
+        if existing_table_obj is not None:
+            self._values["existing_table_obj"] = existing_table_obj
+        if existing_topic_obj is not None:
+            self._values["existing_topic_obj"] = existing_topic_obj
+        if existing_vpc is not None:
+            self._values["existing_vpc"] = existing_vpc
+        if glue_job_props is not None:
+            self._values["glue_job_props"] = glue_job_props
+        if kinesis_stream_props is not None:
+            self._values["kinesis_stream_props"] = kinesis_stream_props
+        if lambda_function_props is not None:
+            self._values["lambda_function_props"] = lambda_function_props
+        if media_store_container_props is not None:
+            self._values["media_store_container_props"] = media_store_container_props
+        if queue_props is not None:
+            self._values["queue_props"] = queue_props
+        if secret_props is not None:
+            self._values["secret_props"] = secret_props
+        if topic_props is not None:
+            self._values["topic_props"] = topic_props
+        if topics_props is not None:
+            self._values["topics_props"] = topics_props
+        if vpc_props is not None:
+            self._values["vpc_props"] = vpc_props
+
+    @builtins.property
+    def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+        result = self._values.get("bucket_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+
+    @builtins.property
+    def dead_letter_queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
+        result = self._values.get("dead_letter_queue_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
+
+    @builtins.property
+    def deploy_dead_letter_queue(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("deploy_dead_letter_queue")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def deploy_vpc(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("deploy_vpc")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def dynamo_table_props(self) -> typing.Optional[aws_cdk.aws_dynamodb.TableProps]:
+        result = self._values.get("dynamo_table_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.TableProps], result)
+
+    @builtins.property
+    def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
+        result = self._values.get("encryption_key")
+        return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
+
+    @builtins.property
+    def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
+        result = self._values.get("encryption_key_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_kms.KeyProps], result)
+
+    @builtins.property
+    def endpoint_props(self) -> typing.Optional[aws_cdk.aws_sagemaker.CfnEndpointProps]:
+        result = self._values.get("endpoint_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_sagemaker.CfnEndpointProps], result)
+
+    @builtins.property
+    def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
+        result = self._values.get("existing_bucket_obj")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], result)
+
+    @builtins.property
+    def existing_glue_job(self) -> typing.Optional[aws_cdk.aws_glue.CfnJob]:
+        result = self._values.get("existing_glue_job")
+        return typing.cast(typing.Optional[aws_cdk.aws_glue.CfnJob], result)
+
+    @builtins.property
+    def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
+        result = self._values.get("existing_lambda_obj")
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
+
+    @builtins.property
+    def existing_media_store_container_obj(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_mediastore.CfnContainer]:
+        result = self._values.get("existing_media_store_container_obj")
+        return typing.cast(typing.Optional[aws_cdk.aws_mediastore.CfnContainer], result)
+
+    @builtins.property
+    def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
+        result = self._values.get("existing_queue_obj")
+        return typing.cast(typing.Optional[aws_cdk.aws_sqs.Queue], result)
+
+    @builtins.property
+    def existing_sagemaker_endpoint_obj(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_sagemaker.CfnEndpoint]:
+        result = self._values.get("existing_sagemaker_endpoint_obj")
+        return typing.cast(typing.Optional[aws_cdk.aws_sagemaker.CfnEndpoint], result)
+
+    @builtins.property
+    def existing_secret_obj(self) -> typing.Optional[aws_cdk.aws_secretsmanager.Secret]:
+        result = self._values.get("existing_secret_obj")
+        return typing.cast(typing.Optional[aws_cdk.aws_secretsmanager.Secret], result)
+
+    @builtins.property
+    def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
+        result = self._values.get("existing_stream_obj")
+        return typing.cast(typing.Optional[aws_cdk.aws_kinesis.Stream], result)
+
+    @builtins.property
+    def existing_table_obj(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
+        result = self._values.get("existing_table_obj")
+        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.Table], result)
+
+    @builtins.property
+    def existing_topic_obj(self) -> typing.Optional[aws_cdk.aws_sns.Topic]:
+        result = self._values.get("existing_topic_obj")
+        return typing.cast(typing.Optional[aws_cdk.aws_sns.Topic], result)
+
+    @builtins.property
+    def existing_vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+        result = self._values.get("existing_vpc")
+        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+
+    @builtins.property
+    def glue_job_props(self) -> typing.Optional[aws_cdk.aws_glue.CfnJobProps]:
+        result = self._values.get("glue_job_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_glue.CfnJobProps], result)
+
+    @builtins.property
+    def kinesis_stream_props(self) -> typing.Optional[aws_cdk.aws_kinesis.StreamProps]:
+        result = self._values.get("kinesis_stream_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_kinesis.StreamProps], result)
+
+    @builtins.property
+    def lambda_function_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
+        result = self._values.get("lambda_function_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
+
+    @builtins.property
+    def media_store_container_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_mediastore.CfnContainerProps]:
+        result = self._values.get("media_store_container_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_mediastore.CfnContainerProps], result)
+
+    @builtins.property
+    def queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
+        result = self._values.get("queue_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
+
+    @builtins.property
+    def secret_props(self) -> typing.Optional[aws_cdk.aws_secretsmanager.SecretProps]:
+        result = self._values.get("secret_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_secretsmanager.SecretProps], result)
+
+    @builtins.property
+    def topic_props(self) -> typing.Optional[aws_cdk.aws_sns.TopicProps]:
+        result = self._values.get("topic_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_sns.TopicProps], result)
+
+    @builtins.property
+    def topics_props(self) -> typing.Optional[aws_cdk.aws_sns.TopicProps]:
+        result = self._values.get("topics_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_sns.TopicProps], result)
+
+    @builtins.property
+    def vpc_props(self) -> typing.Optional[aws_cdk.aws_ec2.VpcProps]:
+        result = self._values.get("vpc_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_ec2.VpcProps], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "VerifiedProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 __all__ = [
     "AddProxyMethodToApiResourceInputParams",
     "BuildDeadLetterQueueProps",
@@ -1598,6 +1945,7 @@ __all__ = [
     "ServiceEndpointTypes",
     "SinkDataStoreProps",
     "SinkStoreType",
+    "VerifiedProps",
 ]
 
 publication.publish()
