@@ -33,16 +33,18 @@ import aws_cdk.aws_s3._jsii
 import aws_cdk.aws_s3_assets._jsii
 import aws_cdk.aws_s3_notifications._jsii
 import aws_cdk.aws_sagemaker._jsii
+import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.aws_sns._jsii
 import aws_cdk.aws_sqs._jsii
+import aws_cdk.aws_ssm._jsii
 import aws_cdk.aws_stepfunctions._jsii
 import aws_cdk.core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/core",
-    "1.100.0",
+    "1.103.0",
     __name__[0:-6],
-    "core@1.100.0.jsii.tgz",
+    "core@1.103.0.jsii.tgz",
 )
 
 __all__ = [
